@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# $Id: wheel_run.pm 2362 2008-06-27 04:50:41Z rcaputo $
+# $Id: wheel_run.pm 2411 2009-01-30 07:04:44Z rcaputo $
 
 use strict;
 use lib qw(./mylib ../mylib);
@@ -546,7 +546,8 @@ for my $chld_program (@chld_programs) {
     skip "$chld_name/pty: The underlying event loop has trouble with ptys on $^O", 2*STD_TEST_COUNT
       if $^O eq "darwin" and (
         exists $INC{"POE/Loop/IO_Poll.pm"} or
-        exists $INC{"POE/Loop/Event.pm"}
+        exists $INC{"POE/Loop/Event.pm"} or
+        $ENV{POE_LOOP_USES_POLL}
       );
 
     create_test_session(
