@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# $Id: wheel_tail.pm 2209 2007-08-11 09:14:58Z rcaputo $
+# $Id: wheel_tail.pm 2477 2009-03-01 13:31:26Z apocal $
 
 # Exercises Wheel::FollowTail, Wheel::ReadWrite, and Filter::Block.
 # -><- Needs tests for Seek and SeekBack.
@@ -22,6 +22,22 @@ if ($^O eq "cygwin") {
   plan skip_all => "Cygwin file open/locking semantics thwart this test.";
 }
 
+# to work around an issue on MSWin32+old perls
+# it always hangs on the 7th test...
+if ($^O eq 'MSWin32') {
+  if ($] < 5.008) {
+    plan skip_all => "This test always hangs on MSWin32+perl older than 5.8.0";
+  }
+  if ($] < 5.010) {
+    # ARGH, it doesn't lock up on Strawberry 5.8.x but it does on ActiveState 5.8.x!!!
+    # ugly method, but it works for me...
+    require Config;
+    if ($Config::Config{cf_email} =~ /ActiveState/) {
+      plan skip_all => "This test always hangs on MSWin32+ActiveState perl older than 5.10";
+    }
+  }
+}
+
 plan tests => 10;
 
 use POE qw(
